
// ADC and Timer 2 Initialization

void setupADC()
{
  // ADC Free-Run on A07 Setup

  // clear ADLAR in ADMUX (0x7C) to right-adjust the result
  // ADCL will contain lower 8 bits, ADCH upper 2 (in last two bits)
  ADMUX &= B11011111;

  // Set REFS1..0 in ADMUX (0x7C) to change reference voltage to the
  // proper source (01)
  ADMUX |= B01000000;

  // Clear MUX3..0 in ADMUX (0x7C)
  ADMUX &= B11110000;

  // Set MUX3..0 in ADMUX (0x7C) to read from A07
  // Encoder seitch select ADC read of A7
  ADMUX |= B00000111;

  // Set ADEN in ADCSRA (0x7A) to enable the ADC.
  ADCSRA |= B10000000;

  // Set ADATE in ADCSRA (0x7A) to enable auto-triggering.
  ADCSRA |= B00100000;
  //ADCSRA |= B00000000; //disable auto

  // Clear ADTS2..0 in ADCSRB (0x7B) to set trigger mode to free running.
  ADCSRB &= B11111000;

  // Set the Prescaler to 128 (16000KHz/128 = 125KHz)
  ADCSRA |= B00000111;

  // Kick off the first ADC
  ADCSRA |= B01000000;

  //--------------------------------------

  // TIMER 2 setup
  // used for PWM/ the DENSITY OUT

  pinMode(3, OUTPUT);

  // PWM output on pin D11
  pinMode(11, OUTPUT);

  // Init Timer 2
  TCCR2A = _BV(COM2A1) | _BV(COM2B1) | _BV(WGM21) | _BV(WGM20);

  // prescale set to none
  // PWM frequency = 62.5khz
  TCCR2B = _BV(CS20);

  // arbitrary starting duty cycle on pin 11
  OCR2A = 180;

  // PWM on pin 3 to zero
  // PIN3 is used by LED driver chip
  OCR2B = 00;
}

//----------------------------------------------------------------------------

// Read ADC conversion result into variable aval
ISR(ADC_vect)
{
  aval = ADCL | (ADCH << 8);
}


// END OF PAGE
